--
-- Filename: changeSettingsEvent.lua
-- Author: Martin Fabík (LoogleCZ)
--
-- This event is part of NotesMod.
--

changeSettingsEvent = {};
changeSettingsEvent_mt = Class(changeSettingsEvent, Event);

InitEventClass(changeSettingsEvent, "changeSettingsEvent");

function changeSettingsEvent:emptyNew()
    local self = Event:new(changeSettingsEvent_mt);
    return self;
end;

function changeSettingsEvent:new(settings)
    local self = changeSettingsEvent:emptyNew();
	self.settings = settings;
    return self;
end;

function changeSettingsEvent:readStream(streamId, connection)
	self.settings = {};
	self.settings.addNote = streamReadInt8(streamId);
	self.settings.removeNote = streamReadInt8(streamId);
	self.settings.editNote = streamReadInt8(streamId);
	self.settings.maxItemsPerUser = streamReadInt8(streamId);
	self.settings.afterEditNote = streamReadInt8(streamId);
	self:run(connection);
end;

function changeSettingsEvent:writeStream(streamId, connection)
	streamWriteInt8(streamId, self.settings.addNote);
	streamWriteInt8(streamId, self.settings.removeNote);
	streamWriteInt8(streamId, self.settings.editNote);
	streamWriteInt8(streamId, self.settings.maxItemsPerUser);
	streamWriteInt8(streamId, self.settings.afterEditNote);
end;

function changeSettingsEvent:run(connection)
	g_currentMission.NotesBase.settings.userAddNotes = self.settings.addNote;
	g_currentMission.NotesBase.settings.userDeleteNotes = self.settings.removeNote;
	g_currentMission.NotesBase.settings.usersEditNotes = self.settings.editNote;
	g_currentMission.NotesBase.settings.userMaxNoteCount = self.settings.maxItemsPerUser;
	g_currentMission.NotesBase.settings.afterEditNote = self.settings.afterEditNote;
	if g_currentMission.NotesBase.isClient then
		g_currentMission.NotesBase.settingsGUIElements.userAddEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userAddNotes);
		g_currentMission.NotesBase.settingsGUIElements.userDeletePerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userDeleteNotes);
		g_currentMission.NotesBase.settingsGUIElements.userEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.usersEditNotes);
		g_currentMission.NotesBase.settingsGUIElements.maxItemsPerUserPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userMaxNoteCount);
		g_currentMission.NotesBase.settingsGUIElements.afterEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.afterEditNote);
		
		if g_currentMission.NotesBase.selectedIndex ~= nil then
			if (g_currentMission.NotesBase.settings.userDeleteNotes == 2 and (g_currentMission.player.controllerName == g_currentMission.NotesBase.notes[g_currentMission.NotesBase.selectedIndex].author or g_client.networkListener.isMasterUser or (g_currentMission.NotesBase.isClient and g_currentMission.NotesBase.isServer))) or g_currentMission.NotesBase.settings.userDeleteNotes == 1 then
				g_currentMission.NotesBase.noteElements.btnRemove:setVisibility(true);
			else
				g_currentMission.NotesBase.noteElements.btnRemove:setVisibility(false);
			end;
			if (g_currentMission.NotesBase.settings.usersEditNotes == 2 and (g_currentMission.player.controllerName == g_currentMission.NotesBase.notes[g_currentMission.NotesBase.selectedIndex].author or g_client.networkListener.isMasterUser or (g_currentMission.NotesBase.isClient and g_currentMission.NotesBase.isServer))) or g_currentMission.NotesBase.settings.usersEditNotes == 1 then
				g_currentMission.NotesBase.noteElements.btnEdit:setVisibility(true);
			else
				g_currentMission.NotesBase.noteElements.btnEdit:setVisibility(false);
			end;
		end;
		
	end;
	if not connection:getIsServer() then
		g_server:broadcastEvent(changeSettingsEvent:new(self.settings));
	end;
end;

function changeSettingsEvent:sendEvent(settings)
	if g_server ~= nil then
		g_currentMission.NotesBase.settings.userAddNotes = settings.addNote;
		g_currentMission.NotesBase.settings.userDeleteNotes = settings.removeNote;
		g_currentMission.NotesBase.settings.usersEditNotes = settings.editNote;
		g_currentMission.NotesBase.settings.userMaxNoteCount = settings.maxItemsPerUser;
		g_currentMission.NotesBase.settings.afterEditNote = settings.afterEditNote;
		if g_currentMission.NotesBase.isClient then
			g_currentMission.NotesBase.settingsGUIElements.userAddEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userAddNotes);
			g_currentMission.NotesBase.settingsGUIElements.userDeletePerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userDeleteNotes);
			g_currentMission.NotesBase.settingsGUIElements.userEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.usersEditNotes);
			g_currentMission.NotesBase.settingsGUIElements.maxItemsPerUserPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.userMaxNoteCount);
			g_currentMission.NotesBase.settingsGUIElements.afterEditPerm:setHighestVisibleEntry(g_currentMission.NotesBase.settings.afterEditNote);
		end;
		g_server:broadcastEvent(changeSettingsEvent:new(settings));
	else
		g_client:getServerConnection():sendEvent(changeSettingsEvent:new(settings));
	end;
end;
